@@ -8,6 +8,8 @@ import os
 
 import click
 
+
+
 # initialize connection to our
 # email server, we will use gmail here
 smtp = smtplib.SMTP('smtp.gmail.com', 587)
@@ -46,12 +48,15 @@ def message(subject, text, img, attachment):
 
 
 
-@click.command()
+CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
+
+@click.command(context_settings=CONTEXT_SETTINGS)
 @click.option(
         '-s',
         '--subject',
         prompt=True,
         default="Hello there",
+        show_default=True,
         help="Subject of the email"
         )
 @click.option(
@@ -59,26 +64,33 @@ def message(subject, text, img, attachment):
         '--mail',
         prompt=True,
         default="Message",
+        show_default=True,
         help="Message text"
         )
 @click.option(
         '-i',
         '--image',
         prompt=True,
+        type=click.Path(),
         default='None',
+        show_default=True,
         help="Image path"
         )
 @click.option(
         '-a',
         '--attachment',
         prompt=True,
+        type=click.Path(),
         default='None',
+        show_default=True,
         help="Document attachment"
         )
 @click.option(
         '-t',
         '--to',
         prompt=True,
+        default='vaibhavblayer@gmail.com',
+        show_default=True,
         help="Email id to send to"
         )
 def main(subject, mail, image, attachment, to):
